package fr.velossity.sample.device.impl;

import java.util.Hashtable;

import org.osgi.framework.BundleContext;
import org.osgi.service.wireadmin.Consumer;
import org.osgi.service.wireadmin.Wire;
import org.osgi.service.wireadmin.WireConstants;

import fr.velossity.sample.device.Measurement;

/**
 * 
 * @author C. Saint-Marcel
 * 
 */
public class ConsumerImpl implements Consumer {

	private String name;
	
	public ConsumerImpl(String name) {
		this.name = name;
	}

	/**
	 */
	public void activate(BundleContext context) throws Exception {
		Hashtable prop = new Hashtable();
		// this property shows that the consumer will accept any measurement data types
		prop.put(WireConstants.WIREADMIN_CONSUMER_FLAVORS,
				new Class[] { Measurement.class });
		// the identifier property of the consumer
		prop.put("service.pid", name);
		// PUBLISHES the Consumer service
		context.registerService(Consumer.class.getName(), this, prop);
	}

	/**
	 */
	public void deactivate(BundleContext context) throws Exception {
	}

	/**
	 * Watches the list of wires.
	 * 
	 * @see ConsumerImpl#producersConnected(Wire[])
	 */
	public void producersConnected(Wire[] wires) {
		if (wires == null) {
			System.out.println("Not connected to any wires");
		} else {
			System.out.println("Connected to " + wires.length + " wires");
		}
	}

	/**
	 * Receives the new data whenever such are available.
	 * 
	 * @see ConsumerImpl#updated(Wire, Object)
	 */
	public void updated(Wire wire, Object value) {
		Measurement measurement = (Measurement) value;
		System.out.println("New measure ["
				+ measurement.getSource().getIdentifier() + "]= "
				+ measurement.getValue() + " " + measurement.getUnit());
	}

}
